#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-atk
version:                2.0.28
visibility:             public
id:                     gi-atk-2.0.28-F4FBvs1Eed93YqyPKBoPOX
key:                    gi-atk-2.0.28-F4FBvs1Eed93YqyPKBoPOX
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Atk bindings
description:            Bindings for Atk, autogenerated by haskell-gi.
category:               Bindings
abi:                    0693f4791cc1d6e1e2216a0933795582
exposed:                True
exposed-modules:
    GI.Atk GI.Atk.Callbacks GI.Atk.Config GI.Atk.Constants GI.Atk.Enums
    GI.Atk.Flags GI.Atk.Functions GI.Atk.Interfaces
    GI.Atk.Interfaces.Action GI.Atk.Interfaces.Component
    GI.Atk.Interfaces.Document GI.Atk.Interfaces.EditableText
    GI.Atk.Interfaces.HyperlinkImpl GI.Atk.Interfaces.Hypertext
    GI.Atk.Interfaces.Image GI.Atk.Interfaces.ImplementorIface
    GI.Atk.Interfaces.Selection GI.Atk.Interfaces.StreamableContent
    GI.Atk.Interfaces.Table GI.Atk.Interfaces.TableCell
    GI.Atk.Interfaces.Text GI.Atk.Interfaces.Value
    GI.Atk.Interfaces.Window GI.Atk.Objects
    GI.Atk.Objects.GObjectAccessible GI.Atk.Objects.Hyperlink
    GI.Atk.Objects.Misc GI.Atk.Objects.NoOpObject
    GI.Atk.Objects.NoOpObjectFactory GI.Atk.Objects.Object
    GI.Atk.Objects.ObjectFactory GI.Atk.Objects.Plug
    GI.Atk.Objects.Registry GI.Atk.Objects.Relation
    GI.Atk.Objects.RelationSet GI.Atk.Objects.Socket
    GI.Atk.Objects.StateSet GI.Atk.Objects.Util GI.Atk.Structs
    GI.Atk.Structs.Attribute GI.Atk.Structs.Implementor
    GI.Atk.Structs.KeyEventStruct GI.Atk.Structs.PropertyValues
    GI.Atk.Structs.Range GI.Atk.Structs.Rectangle
    GI.Atk.Structs.TextRange GI.Atk.Structs.TextRectangle
    GI.Atk.Structs.TextSelection

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-atk-2.0.28
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-atk-2.0.28 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-atk-2.0.28 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-atk
hs-libraries:           HSgi-atk-2.0.28-F4FBvs1Eed93YqyPKBoPOX
extra-libraries:        atk-1.0 gobject-2.0 glib-2.0
extra-libraries-static:
    atk-1.0 gobject-2.0 glib-2.0 atomic m sysprof-capture-4 pcre2-8
    pthread ffi

include-dirs:
    /usr/include/atk-1.0 /usr/include /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-GQdzVbXRko071pCrqOIWOd
    gi-gobject-2.0.31-JrRju07j0QqF7a6qbUhWpF
    haskell-gi-0.26.16-DT0fMT4725hIpjqfyuoqdQ
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-atk/html/gi-atk.haddock
haddock-html:           /usr/share/doc/haskell-gi-atk/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

